nxp-pac

Crates

git

Versions

lpc55s69_cm33_core0

Flavors

Tcr

Struct Tcr 

#[repr(transparent)]
pub struct Tcr(pub u32);
Timer Control Register. The TCR is used to control the Timer Counter functions. The Timer Counter can be disabled or reset through the TCR.

Tuple Fields

0: u32

Implementations

Source

impl Tcr

pub const fn cen(&self) -> bool

Counter enable.

pub const fn set_cen(&mut self, val: bool)

Counter enable.

pub const fn crst(&self) -> bool

Counter reset.

pub const fn set_crst(&mut self, val: bool)

Counter reset.